# pytket-projectq

[pytket](https://github.com/CQCL/pytket) is a python module for interfacing with CQC t|ket>, a set of quantum programming tools.

[ProjectQ](https://github.com/ProjectQ-Framework/ProjectQ) is an open-source library for quantum circuit compilation and simulation.

This is an extension to ``pytket`` which allows conversion to and from the ProjectQ primitives.

### Getting Started
``pytket-projectq`` is available for ``python3.6`` or higher, on Linux and MacOS.
To install, run 

``pip install pytket-projectq``

**Documentation** can be found at [cqcl.github.io/pytket](https://cqcl.github.io/pytket)

### LICENCE

Copyright 2019 Cambridge Quantum Computing

Licensed under a Non-Commercial Use Software Licence (the "Licence");
you may not use this product except in compliance with the Licence.
You may obtain a copy of the Licence in the LICENCE file accompanying
these documents or view them [here](https://cqcl.github.io/pytket/build/html/licence.html).

Unless required by applicable law or agreed to in writing, software
distributed under the Licence is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the Licence for the specific language governing permissions and
limitations under the Licence, but note it is strictly for non-commercial use.
